@@ -9,26 +9,14 @@ from .const import (
     SystemType,
     VelisDeviceAttribute,
     WheType,
-    PlantMode,
-    ZoneMode,
-    ConsumptionProperties,
-    ConsumptionType,
-    CustomDeviceFeatures,
-    MedDeviceSettings,
-    VelisDeviceProperties,
-    EvoDeviceProperties,
-    NuosSplitProperties,
-    DeviceProperties,
-    DeviceFeatures,
-    ThermostatProperties,
 )
+from .bsb_device import AristonBsbDevice
 from .lux_device import AristonLuxDevice
+from .lux2_device import AristonLux2Device
 from .evo_device import AristonEvoDevice
 from .galevo_device import AristonGalevoDevice
 from .lydos_hybrid_device import AristonLydosHybridDevice
-from .velis_device import AristonVelisDevice
 from .nuos_split_device import AristonNuosSplitDevice
-from .evo_lydos_device import AristonEvoLydosDevice
 from .device import AristonDevice
 
 _LOGGER = logging.getLogger(__name__)
@@ -84,7 +72,7 @@ def _get_device(
         None,
     )
     if device is None:
-        _LOGGER.exception(f'No device "{gateway}" found.')
+        _LOGGER.exception("No device %s found.", gateway)
         return None
 
     system_type = device.get(DeviceAttribute.SYS)
@@ -117,10 +105,23 @@ def _get_device(
                 api,
                 device,
             )
-        _LOGGER.exception(f"Unsupported whe type {whe_type}")
+        if whe_type == WheType.Andris2.value:
+            return AristonEvoDevice(
+                api,
+                device,
+            )
+        if whe_type == WheType.Lux2.value:
+            return AristonLux2Device(
+                api,
+                device,
+            )
+        _LOGGER.exception("Unsupported whe type %s", whe_type)
         return None
 
-    _LOGGER.exception(f"Unsupported system type {system_type}")
+    if system_type == SystemType.BSB.value:
+        return AristonBsbDevice(api, device)
+
+    _LOGGER.exception("Unsupported system type %s", system_type)
     return None
 
 
