@@ -10,6 +10,7 @@ import requests
 from .const import (
     ARISTON_API_URL,
     ARISTON_BSB_ZONES,
+    ARISTON_BUS_ERRORS,
     ARISTON_DATA_ITEMS,
     ARISTON_LITE,
     ARISTON_LOGIN,
@@ -291,7 +292,7 @@ class AristonAPI:
             },
         )
 
-    def set_nuos_temperature(self, gw_id: str, comfort: float, reduced: float) -> None:
+    def set_nuos_temperature(self, gw_id: str, comfort: float, reduced: float, old_comfort: Optional[float], old_reduced: Optional[float]) -> None:
         """Set Nuos temperature"""
         self._post(
             f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Slp.value}/{gw_id}/temperatures",
@@ -299,6 +300,10 @@ class AristonAPI:
                 "new": {
                     "comfort": comfort,
                     "reduced": reduced,
+                },
+                "old": {
+                    "comfort": old_comfort,
+                    "reduced": old_reduced,
                 }
             },
         )
@@ -399,6 +404,13 @@ class AristonAPI:
             },
         )
 
+    def get_bus_errors(self, gw_id: str) -> list[Any]:
+        """Get bus errors"""
+        bus_errors = self._get(f"{ARISTON_API_URL}{ARISTON_BUS_ERRORS}?gatewayId={gw_id}&blockingOnly=False&culture=en-US")
+        if bus_errors is not None:
+            return list(bus_errors)
+        return []
+
     def __request(
         self,
         method: str,
@@ -684,7 +696,7 @@ class AristonAPI:
         )
 
     async def async_set_nuos_temperature(
-        self, gw_id: str, comfort: float, reduced: float
+        self, gw_id: str, comfort: float, reduced: float, old_comfort: Optional[float], old_reduced: Optional[float]
     ) -> None:
         """Async set Velis Lydos temperature"""
         await self._async_post(
@@ -693,6 +705,10 @@ class AristonAPI:
                 "new": {
                     "comfort": comfort,
                     "reduced": reduced,
+                },
+                "old": {
+                    "comfort": old_comfort,
+                    "reduced": old_reduced,
                 }
             },
         )
@@ -795,6 +811,13 @@ class AristonAPI:
             },
         )
 
+    async def async_get_bus_errors(self, gw_id: str) -> list[Any]:
+        """Async get bus errors"""
+        bus_errors = await self._async_get(f"{ARISTON_API_URL}{ARISTON_BUS_ERRORS}?gatewayId={gw_id}&blockingOnly=False&culture=en-US")
+        if bus_errors is not None:
+            return list(bus_errors)
+        return []
+
     async def __async_request(
         self,
         method: str,
