@@ -13,18 +13,22 @@ _LOGGER = logging.getLogger(__name__)
 class AristonEvoLydosDevice(AristonVelisDevice):
     """Class representing a physical device, it's state and properties."""
 
-    def get_water_heater_current_temperature(self) -> Optional[float]:
+    @property
+    def water_heater_current_temperature(self) -> Optional[float]:
         """Get water heater current temperature"""
         return self.data.get(EvoLydosDeviceProperties.TEMP, None)
 
-    def get_water_heater_target_temperature(self) -> Optional[float]:
+    @property
+    def water_heater_target_temperature(self) -> Optional[float]:
         """Get water heater target temperature"""
         return self.data.get(EvoLydosDeviceProperties.REQ_TEMP, None)
 
-    def get_av_shw_value(self) -> Optional[int]:
+    @property
+    def av_shw_value(self) -> Optional[int]:
         """Get average showers value"""
         return self.data.get(EvoLydosDeviceProperties.AV_SHW, None)
 
-    def get_is_heating(self) -> Optional[bool]:
+    @property
+    def is_heating(self) -> Optional[bool]:
         """Get is the water heater heating"""
         return self.data.get(EvoLydosDeviceProperties.HEAT_REQ, None)
